@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -24,9 +24,9 @@
 #include <gst/gst.h>
 #include <gst/audio/streamvolume.h>
 
-#include "additions/glib-object.h"
-#include "additions/gst.h"
+#include "framework/glib-object-additions.h"
 #include "framework/gv-framework.h"
+#include "core/gst-additions.h"
 #include "core/gv-core-enum-types.h"
 #include "core/gv-core-internal.h"
 #include "core/gv-metadata.h"
@@ -1168,7 +1168,7 @@ gv_engine_class_init(GvEngineClass *class)
 
 	properties[PROP_STATE] =
 	        g_param_spec_enum("state", "Playback state", NULL,
-	                          GV_ENGINE_STATE_ENUM_TYPE,
+	                          GV_TYPE_ENGINE_STATE,
 	                          GV_ENGINE_STATE_STOPPED,
 	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
 
