@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -24,7 +24,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
-#include "additions/glib-object.h"
+#include "framework/glib-object-additions.h"
 #include "framework/gv-framework.h"
 #include "core/gv-engine.h"
 #include "core/gv-core-enum-types.h"
@@ -984,7 +984,7 @@ gv_player_class_init(GvPlayerClass *class)
 	/* Player properties */
 	properties[PROP_STATE] =
 	        g_param_spec_enum("state", "Playback state", NULL,
-	                          GV_PLAYER_STATE_ENUM_TYPE,
+	                          GV_TYPE_PLAYER_STATE,
 	                          GV_PLAYER_STATE_STOPPED,
 	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
 
