@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,11 +19,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <errno.h>
 #include <string.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <glib-object.h>
 
-#include "additions/glib-object.h"
+#include "framework/glib-object-additions.h"
 #include "framework/gv-framework.h"
 
 #include "core/gv-station-list.h"
@@ -32,51 +34,73 @@
 //        It might be slow. The implementation never tried to be fast.
 
 /*
- * FIP <http://www.fipradio.fr/>
+ * FIP <https://www.fip.fr/>
  * Just the best radios you'll ever listen to.
  */
 
-#define FIP_STATIONS      \
+#define FIP_STATIONS \
         "<Station>" \
         "  <name>FIP Paris</name>" \
-        "  <uri>http://direct.fipradio.fr/live/fip-midfi.mp3</uri>" \
+        "  <uri>https://direct.fipradio.fr/live/fip-midfi.mp3</uri>" \
         "</Station>" \
         "<Station>" \
         "  <name>FIP Autour du Rock</name>" \
-        "  <uri>http://direct.fipradio.fr/live/fip-webradio1.mp3</uri>" \
+        "  <uri>https://direct.fipradio.fr/live/fip-webradio1.mp3</uri>" \
         "</Station>" \
         "<Station>" \
         "  <name>FIP Autour du Jazz</name>" \
-        "  <uri>http://direct.fipradio.fr/live/fip-webradio2.mp3</uri>" \
+        "  <uri>https://direct.fipradio.fr/live/fip-webradio2.mp3</uri>" \
         "</Station>" \
         "<Station>" \
         "  <name>FIP Autour du Groove</name>" \
-        "  <uri>http://direct.fipradio.fr/live/fip-webradio3.mp3</uri>" \
+        "  <uri>https://direct.fipradio.fr/live/fip-webradio3.mp3</uri>" \
         "</Station>" \
         "<Station>" \
         "  <name>FIP Autour du Monde</name>" \
-        "  <uri>http://direct.fipradio.fr/live/fip-webradio4.mp3</uri>" \
+        "  <uri>https://direct.fipradio.fr/live/fip-webradio4.mp3</uri>" \
         "</Station>" \
         "<Station>" \
         "  <name>FIP Tout nouveau, tout FIP</name>" \
-        "  <uri>http://direct.fipradio.fr/live/fip-webradio5.mp3</uri>" \
+        "  <uri>https://direct.fipradio.fr/live/fip-webradio5.mp3</uri>" \
         "</Station>" \
         "<Station>" \
-        "  <name>FIP Evenementielle</name>" \
-        "  <uri>http://direct.fipradio.fr/live/fip-webradio6.mp3</uri>" \
+        "  <name>FIP Autour du Reggae</name>" \
+        "  <uri>https://direct.fipradio.fr/live/fip-webradio6.mp3</uri>" \
+        "</Station>" \
+        "<Station>" \
+        "  <name>FIP Autour de l'Électro</name>" \
+        "  <uri>https://direct.fipradio.fr/live/fip-webradio8.mp3</uri>" \
+        "</Station>"
+
+/*
+ * Nova <http://www.nova.fr/>
+ * Another killer radio from France.
+ */
+
+#define NOVA_STATIONS \
+        "<Station>" \
+        "  <name>Nova</name>" \
+        "  <uri>http://novazz.ice.infomaniak.ch/novazz-128.mp3</uri>" \
+        "</Station>" \
+        "<Station>" \
+        "  <name>Nova Vintage</name>" \
+        "  <uri>http://nova-vnt.ice.infomaniak.ch/nova-vnt-128</uri>" \
+        "</Station>" \
+        "<Station>" \
+        "  <name>Nova la Nuit</name>" \
+        "  <uri>http://nova-ln.ice.infomaniak.ch/nova-ln-128</uri>" \
+        "</Station>" \
+        "<Station>" \
+        "  <name>Nova V.F.</name>" \
+        "  <uri>http://nova-vf.ice.infomaniak.ch/nova-vf-128</uri>" \
         "</Station>"
 
 /*
  * More of my favorite french radios.
- * - Nova       <http://www.novaplanet.com/>
  * - Grenouille <http://www.radiogrenouille.com/>
  */
 
 #define FRENCH_STATIONS   \
-        "<Station>" \
-        "  <name>Nova</name>" \
-        "  <uri>http://broadcast.infomaniak.net/radionova-high.mp3</uri>" \
-        "</Station>" \
         "<Station>" \
         "  <name>Radio Grenouille</name>" \
         "  <uri>http://live.radiogrenouille.com/live</uri>" \
@@ -133,27 +157,30 @@
  * Default station list, loaded if no station list file is found
  */
 
-#define DEFAULT_STATIONS_DEV      \
+#define DEFAULT_STATIONS_DEV \
         FIP_STATIONS \
+	NOVA_STATIONS \
         FRENCH_STATIONS \
         TESTING_BROKEN_STATIONS \
         TESTING_PLAYLIST_STATIONS \
-        TESTING_MORE_STATIONS \
+        TESTING_MORE_STATIONS
 
-#define DEFAULT_STATIONS_PROD     \
+#define DEFAULT_STATIONS_PROD \
         FIP_STATIONS \
+	NOVA_STATIONS \
         FRENCH_STATIONS
 
-#define DEFAULT_STATION_LIST      \
+#define DEFAULT_STATION_LIST \
         "<Stations>" \
         DEFAULT_STATIONS_PROD \
         "</Stations>"
 
 /*
- * Save delay - how long do we wait to write configuration to file
+ * More defines...
  */
 
-#define SAVE_DELAY 1
+#define SAVE_DELAY 1 // how long to wait before writing changes to disk
+#define STATION_LIST_FILE "stations.xml" // where to write the stations
 
 /*
  * Signals
@@ -176,8 +203,8 @@ static guint signals[SIGNAL_N];
  */
 
 struct _GvStationListPrivate {
-	/* Load/save pathes */
-	GSList *load_pathes;
+	/* Load/save paths */
+	gchar **load_paths;
 	gchar  *save_path;
 	/* Timeout id, > 0 if a save operation is scheduled */
 	guint   save_source_id;
@@ -202,6 +229,16 @@ G_DEFINE_TYPE_WITH_CODE(GvStationList, gv_station_list, G_TYPE_OBJECT,
                         G_ADD_PRIVATE(GvStationList)
                         G_IMPLEMENT_INTERFACE(GV_TYPE_ERRORABLE, NULL))
 
+/*
+ * Helpers
+ */
+
+static gpointer
+copy_func_object_ref(gconstpointer src, gpointer data G_GNUC_UNUSED)
+{
+	return g_object_ref((gpointer) src);
+}
+
 /*
  * Markup handling
  */
@@ -453,7 +490,7 @@ gv_station_list_iter_new(GvStationList *self)
 	GvStationListIter *iter;
 
 	iter = g_new0(GvStationListIter, 1);
-	iter->head = g_list_copy_deep(list, (GCopyFunc) g_object_ref, NULL);
+	iter->head = g_list_copy_deep(list, copy_func_object_ref, NULL);
 	iter->item = iter->head;
 
 	return iter;
@@ -659,7 +696,7 @@ gv_station_list_remove(GvStationList *self, GvStation *station)
 	if (priv->shuffled) {
 		g_list_free_full(priv->shuffled, g_object_unref);
 		priv->shuffled = g_list_copy_deep_shuffle(priv->stations,
-		                 (GCopyFunc) g_object_ref, NULL);
+		                 copy_func_object_ref, NULL);
 	}
 
 	/* Emit a signal */
@@ -708,7 +745,7 @@ gv_station_list_insert(GvStationList *self, GvStation *station, gint pos)
 	if (priv->shuffled) {
 		g_list_free_full(priv->shuffled, g_object_unref);
 		priv->shuffled = g_list_copy_deep_shuffle(priv->stations,
-		                 (GCopyFunc) g_object_ref, NULL);
+		                 copy_func_object_ref, NULL);
 	}
 
 	/* Emit a signal */
@@ -830,7 +867,7 @@ gv_station_list_prev(GvStationList *self, GvStation *station,
 	if (shuffle) {
 		if (priv->shuffled == NULL) {
 			priv->shuffled = g_list_copy_deep_shuffle(priv->stations,
-			                 (GCopyFunc) g_object_ref, NULL);
+			                 copy_func_object_ref, NULL);
 		}
 		stations = priv->shuffled;
 	} else {
@@ -896,7 +933,7 @@ gv_station_list_next(GvStationList *self, GvStation *station,
 	if (shuffle) {
 		if (priv->shuffled == NULL) {
 			priv->shuffled = g_list_copy_deep_shuffle(priv->stations,
-			                 (GCopyFunc) g_object_ref, NULL);
+			                 copy_func_object_ref, NULL);
 		}
 		stations = priv->shuffled;
 	} else {
@@ -1066,18 +1103,27 @@ gv_station_list_save(GvStationList *self)
 {
 	GvStationListPrivate *priv = self->priv;
 	GError *err = NULL;
-	gchar *text;
+	gchar *dirname = NULL;
+	gchar *text = NULL;
 
 	/* Stringify data */
 	text = print_markup(priv->stations, &err);
 	if (err)
 		goto cleanup;
 
+	/* Create directory */
+	dirname = g_path_get_dirname(priv->save_path);
+	if (g_mkdir_with_parents(dirname, S_IRWXU) != 0) {
+		WARNING("Failed to make directory '%s': %s", dirname, strerror(errno));
+		goto cleanup;
+	}
+
 	/* Write to file */
-	gv_file_write_sync(priv->save_path, text, &err);
+	g_file_set_contents(priv->save_path, text, -1, &err);
 
 cleanup:
 	/* Cleanup */
+	g_free(dirname);
 	g_free(text);
 
 	/* Handle error */
@@ -1096,22 +1142,28 @@ void
 gv_station_list_load(GvStationList *self)
 {
 	GvStationListPrivate *priv = self->priv;
-	GSList *item = NULL;
-	GList *sta_item;
+	const gchar *loaded_path = NULL;
+	guint i, n_paths;
+	GList *item;
 
 	TRACE("%p", self);
 
 	/* This should be called only once at startup */
 	g_assert_null(priv->stations);
 
-	/* Load from a list of pathes */
-	for (item = priv->load_pathes; item; item = item->next) {
+	/* Load from a list of paths */
+	n_paths = g_strv_length(priv->load_paths);
+	for (i = 0; i < n_paths; i++) {
+		const gchar *path = priv->load_paths[i];
 		GError *err = NULL;
-		const gchar *path = item->data;
 		gchar *text;
 
+		/* Check if the file exists */
+		if (!g_file_test(path, G_FILE_TEST_EXISTS))
+			continue;
+
 		/* Attempt to read file */
-		gv_file_read_sync(path, &text, &err);
+		g_file_get_contents(path, &text, NULL, &err);
 		if (err) {
 			WARNING("%s", err->message);
 			g_clear_error(&err);
@@ -1128,13 +1180,12 @@ gv_station_list_load(GvStationList *self)
 		}
 
 		/* Success */
+		loaded_path = path;
 		break;
 	}
 
 	/* Check if we got something */
-	if (item) {
-		const gchar *loaded_path = item->data;
-
+	if (loaded_path) {
 		INFO("Station list loaded from file '%s'", loaded_path);
 	} else {
 		GError *err = NULL;
@@ -1152,8 +1203,8 @@ gv_station_list_load(GvStationList *self)
 	DEBUG("Station list has %u stations", gv_station_list_length(self));
 
 	/* Register a notify handler for each station */
-	for (sta_item = priv->stations; sta_item; sta_item = sta_item->next) {
-		GvStation *station = sta_item->data;
+	for (item = priv->stations; item; item = item->next) {
+		GvStation *station = item->data;
 
 		g_signal_connect_object(station, "notify", G_CALLBACK(on_station_notify), self, 0);
 	}
@@ -1180,6 +1231,78 @@ gv_station_list_new(void)
  * GObject methods
  */
 
+static gchar **
+make_station_list_load_paths(void)
+{
+	const gchar *const *system_dirs;
+	const gchar *user_dir;
+	guint i, n_dirs;
+	gchar **dirs;
+
+	system_dirs = gv_get_app_system_data_dirs();
+	user_dir = gv_get_app_user_data_dir();
+
+	n_dirs = g_strv_length((gchar **) system_dirs) + 1;
+	dirs = g_malloc0_n(n_dirs + 1, sizeof(gchar *));
+	dirs[0] = g_build_filename(user_dir, STATION_LIST_FILE, NULL);
+	for (i = 1; i < n_dirs; i++) {
+		const gchar *dir;
+		dir = system_dirs[i - 1];
+		dirs[i] = g_build_filename(dir, STATION_LIST_FILE, NULL);
+	}
+
+	return dirs;
+}
+
+static gchar *
+make_station_list_save_path(void)
+{
+	const gchar *user_dir;
+	gchar *dir;
+
+	user_dir = gv_get_app_user_data_dir();
+	dir = g_build_filename(user_dir, STATION_LIST_FILE, NULL);
+
+	return dir;
+}
+
+static void
+move_station_list_file(const gchar *new_file)
+{
+	const gchar *user_config_dir;
+	gchar *old_file = NULL;
+	gchar *dirname = NULL;
+
+	user_config_dir = gv_get_app_user_config_dir();
+	old_file = g_build_filename(user_config_dir, "stations", NULL);
+
+	if (!g_file_test(old_file, G_FILE_TEST_EXISTS))
+		goto cleanup;
+
+	INFO("Station list migration: '%s' > '%s'", old_file, new_file);
+
+	dirname = g_path_get_dirname(new_file);
+	if (g_mkdir_with_parents(dirname, S_IRWXU) != 0) {
+		WARNING("Failed to make directory '%s': %s",
+			dirname, strerror(errno));
+		goto cleanup;
+	}
+	g_free(dirname);
+
+	if (g_rename(old_file, new_file) != 0) {
+		WARNING("Failed to rename file '%s' to '%s': %s",
+			old_file, new_file, strerror(errno));
+		goto cleanup;
+	}
+
+	dirname = g_path_get_dirname(old_file);
+	g_rmdir(dirname);
+
+ cleanup:
+	g_free(dirname);
+	g_free(old_file);
+}
+
 static void
 gv_station_list_finalize(GObject *object)
 {
@@ -1209,9 +1332,9 @@ gv_station_list_finalize(GObject *object)
 	}
 	g_list_free(priv->stations);
 
-	/* Free pathes */
+	/* Free paths */
 	g_free(priv->save_path);
-	g_slist_free_full(priv->load_pathes, g_free);
+	g_strfreev(priv->load_paths);
 
 	/* Chain up */
 	G_OBJECT_CHAINUP_FINALIZE(gv_station_list, object);
@@ -1223,10 +1346,12 @@ gv_station_list_constructed(GObject *object)
 	GvStationList *self = GV_STATION_LIST(object);
 	GvStationListPrivate *priv = self->priv;
 
-	/* Initialize pathes */
-	priv->load_pathes = gv_get_existing_path_list
-	                    (GV_DIR_USER_CONFIG | GV_DIR_SYSTEM_CONFIG, "stations");
-	priv->save_path = g_build_filename(gv_get_user_config_dir(), "stations", NULL);
+	/* Initialize paths */
+	priv->load_paths = make_station_list_load_paths();
+	priv->save_path = make_station_list_save_path();
+
+	/* In version 4.1, the station file moved */
+	move_station_list_file(priv->save_path);
 
 	/* Chain up */
 	G_OBJECT_CHAINUP_CONSTRUCTED(gv_station_list, object);
