@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -23,16 +23,16 @@
 #include <gio/gio.h>
 #include <glib-object.h>
 
-#include "additions/glib.h"
-#include "additions/glib-object.h"
+#include "framework/glib-additions.h"
+#include "framework/glib-object-additions.h"
 #include "framework/gv-framework.h"
 #include "core/gv-core.h"
 
 #include "feat/gv-dbus-server.h"
 #include "feat/gv-dbus-server-native.h"
 
-#define DBUS_PATH           PACKAGE_APPLICATION_PATH
-#define DBUS_IFACE_ROOT     PACKAGE_APPLICATION_ID
+#define DBUS_PATH           GV_APPLICATION_PATH
+#define DBUS_IFACE_ROOT     GV_APPLICATION_ID
 #define DBUS_IFACE_PLAYER   DBUS_IFACE_ROOT ".Player"
 #define DBUS_IFACE_STATIONS DBUS_IFACE_ROOT ".Stations"
 
