@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -21,8 +21,8 @@
 
 #include <glib-object.h>
 
-#include "framework/log.h"
-#include "framework/gv-configurable.h"
+#include "gv-configurable.h"
+#include "log.h"
 
 /*
  * GObject definitions
