@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -29,7 +29,7 @@ struct options {
 	const gchar *log_level;
 	const gchar *output_file;
 	gboolean     print_version;
-#ifdef UI_ENABLED
+#ifdef GV_UI_ENABLED
 	gboolean     without_ui;
 	gboolean     status_icon;
 #endif
