@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -23,19 +23,18 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "additions/glib-object.h"
-#include "additions/gtk.h"
+#include "framework/glib-object-additions.h"
 #include "framework/gv-framework.h"
 #include "core/gv-core.h"
+#include "ui/gtk-additions.h"
 #include "ui/gv-ui-enum-types.h"
 #include "ui/gv-ui-helpers.h"
 #include "ui/gv-ui-internal.h"
-#include "ui/gv-ui-helpers.h"
 #include "ui/gv-stations-tree-view.h"
 
 #include "ui/gv-main-window.h"
 
-#define UI_FILE "main-window.glade"
+#define UI_RESOURCE_PATH GV_APPLICATION_PATH "/Ui/main-window.glade"
 
 /*
  * Properties
@@ -534,7 +533,7 @@ on_stations_tree_view_realize(GtkWidget *stations_tree_view G_GNUC_UNUSED,
 	g_idle_add((GSourceFunc) when_idle_compute_natural_height, self);
 }
 
-static void
+static gboolean
 on_stations_tree_view_map_event(GtkWidget *stations_tree_view G_GNUC_UNUSED,
                                 GdkEvent *event G_GNUC_UNUSED,
                                 GvMainWindowManager *self)
@@ -543,6 +542,8 @@ on_stations_tree_view_map_event(GtkWidget *stations_tree_view G_GNUC_UNUSED,
 	 * height we have is correct.
 	 */
 	g_idle_add((GSourceFunc) when_idle_compute_natural_height, self);
+
+	return GDK_EVENT_PROPAGATE;
 }
 
 /*
@@ -565,17 +566,17 @@ on_popup_window_focus_change(GtkWindow     *window,
 	//DEBUG("Main window %s focus", focus_event->in ? "gained" : "lost");
 
 	if (focus_event->in)
-		return FALSE;
+		return GDK_EVENT_PROPAGATE;
 
 	if (!POPUP_WINDOW_CLOSE_ON_FOCUS_OUT)
-		return FALSE;
+		return GDK_EVENT_PROPAGATE;
 
 	if (gv_stations_tree_view_has_context_menu(stations_tree_view))
-		return FALSE;
+		return GDK_EVENT_PROPAGATE;
 
 	gtk_window_close(window);
 
-	return FALSE;
+	return GDK_EVENT_PROPAGATE;
 }
 
 static gboolean
@@ -590,21 +591,21 @@ on_popup_window_key_press_event(GvMainWindow *self,
 
 	switch (event->keyval) {
 	case GDK_KEY_Escape:
-		/* Close window if 'Esc' key is pressed */
+		/* Close window if <Esc> is pressed */
 		gtk_window_close(GTK_WINDOW(self));
 		break;
 
 	case GDK_KEY_space:
-		/* Play/Stop when space is pressed */
+		/* Toggle playback if <Space> is pressed */
 		gtk_widget_grab_focus(priv->play_button);
 		gv_player_toggle(player);
-		return TRUE;    // consume event
+		return GDK_EVENT_STOP;    // consume event
 
 	default:
 		break;
 	}
 
-	return FALSE;
+	return GDK_EVENT_PROPAGATE;
 }
 
 /*
@@ -623,10 +624,10 @@ on_standalone_window_delete_event(GvMainWindow *self G_GNUC_UNUSED,
 	 * and hiding would make the save operation fail.
 	 */
 
-	/* We must return TRUE here to prevent the window from being destroyed.
+	/* We must stop the event to prevent the window from being destroyed.
 	 * The window will be destroyed later on during the cleanup process.
 	 */
-	return TRUE;
+	return GDK_EVENT_STOP;
 }
 
 static gboolean
@@ -641,21 +642,21 @@ on_standalone_window_key_press_event(GvMainWindow *self,
 
 	switch (event->keyval) {
 	case GDK_KEY_Escape:
-		/* Iconify window if 'Esc' key is pressed */
+		/* Iconify window if <Esc> is pressed */
 		gtk_window_iconify(GTK_WINDOW(self));
 		break;
 
 	case GDK_KEY_space:
-		/* Play/Stop when space is pressed */
+		/* Toggle playback if <Space> is pressed */
 		gtk_widget_grab_focus(priv->play_button);
 		gv_player_toggle(player);
-		return TRUE;    // consume event
+		return GDK_EVENT_STOP;    // consume event
 
 	default:
 		break;
 	}
 
-	return FALSE;
+	return GDK_EVENT_PROPAGATE;
 }
 
 /*
@@ -832,11 +833,9 @@ gv_main_window_populate_widgets(GvMainWindow *self)
 {
 	GvMainWindowPrivate *priv = self->priv;
 	GtkBuilder *builder;
-	gchar *uifile;
 
 	/* Build the ui */
-	gv_builder_load(UI_FILE, &builder, &uifile);
-	DEBUG("Built from ui file '%s'", uifile);
+	builder = gtk_builder_new_from_resource(UI_RESOURCE_PATH);
 
 	/* Save widget pointers */
 
@@ -870,8 +869,7 @@ gv_main_window_populate_widgets(GvMainWindow *self)
 	gtk_container_add(GTK_CONTAINER(self), priv->window_vbox);
 
 	/* Cleanup */
-	g_object_unref(G_OBJECT(builder));
-	g_free(uifile);
+	g_object_unref(builder);
 }
 
 static void
@@ -1114,17 +1112,17 @@ gv_main_window_class_init(GvMainWindowClass *class)
 
 	properties[PROP_THEME_VARIANT] =
 	        g_param_spec_enum("theme-variant", "Theme variant", NULL,
-	                          GV_MAIN_WINDOW_THEME_VARIANT_ENUM_TYPE,
+	                          GV_TYPE_MAIN_WINDOW_THEME_VARIANT,
 	                          GV_MAIN_WINDOW_THEME_DEFAULT,
 	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 
 	/* Register transform function */
-	g_value_register_transform_func(GV_MAIN_WINDOW_THEME_VARIANT_ENUM_TYPE,
+	g_value_register_transform_func(GV_TYPE_MAIN_WINDOW_THEME_VARIANT,
 	                                G_TYPE_STRING,
 	                                gv_value_transform_enum_string);
 	g_value_register_transform_func(G_TYPE_STRING,
-	                                GV_MAIN_WINDOW_THEME_VARIANT_ENUM_TYPE,
+	                                GV_TYPE_MAIN_WINDOW_THEME_VARIANT,
 	                                gv_value_transform_string_enum);
 }
