@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -23,18 +23,17 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "additions/gtk.h"
-#include "additions/glib-object.h"
+#include "framework/glib-object-additions.h"
 #include "framework/gv-framework.h"
 #include "core/gv-core.h"
 #include "feat/gv-feat.h"
+#include "ui/gtk-additions.h"
 #include "ui/gv-ui-enum-types.h"
-#include "ui/gv-ui-helpers.h"
 #include "ui/gv-ui-internal.h"
 
 #include "ui/gv-prefs-window.h"
 
-#define UI_FILE "prefs-window.glade"
+#define UI_RESOURCE_PATH GV_APPLICATION_PATH "/Ui/prefs-window.glade"
 
 /*
  * GObject definitions
@@ -169,7 +168,7 @@ on_window_key_press_event(GvPrefsWindow *self, GdkEventKey *event, gpointer data
 	if (event->keyval == GDK_KEY_Escape)
 		gtk_window_close(window);
 
-	return FALSE;
+	return GDK_EVENT_PROPAGATE;
 }
 
 /*
@@ -339,11 +338,9 @@ gv_prefs_window_populate_widgets(GvPrefsWindow *self)
 {
 	GvPrefsWindowPrivate *priv = self->priv;
 	GtkBuilder *builder;
-	gchar *uifile;
 
 	/* Build the ui */
-	gv_builder_load(UI_FILE, &builder, &uifile);
-	DEBUG("Built from ui file '%s'", uifile);
+	builder = gtk_builder_new_from_resource(UI_RESOURCE_PATH);
 
 	/* Save widget pointers */
 
@@ -404,8 +401,7 @@ gv_prefs_window_populate_widgets(GvPrefsWindow *self)
 	gtk_container_add(GTK_CONTAINER(self), priv->window_vbox);
 
 	/* Cleanup */
-	g_object_unref(G_OBJECT(builder));
-	g_free(uifile);
+	g_object_unref(builder);
 }
 
 static void
