@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -25,10 +25,10 @@
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
-#include "additions/gtk.h"
-#include "additions/glib-object.h"
+#include "framework/glib-object-additions.h"
 #include "framework/gv-framework.h"
 #include "core/gv-core.h"
+#include "ui/gtk-additions.h"
 #include "ui/gv-ui-enum-types.h"
 #include "ui/gv-ui-helpers.h"
 #include "ui/gv-ui-internal.h"
@@ -36,6 +36,7 @@
 
 #include "ui/gv-status-icon.h"
 
+#define UI_RESOURCE_PATH GV_APPLICATION_PATH "/Ui/status-icon-menu.glade"
 #define ICON_MIN_SIZE 16
 
 /*
@@ -246,7 +247,7 @@ on_button_release_event(GtkStatusIcon  *status_icon G_GNUC_UNUSED,
 
 	/* Here we only handle the middle-click */
 	if (event->button != 2)
-		return FALSE;
+		return GDK_EVENT_PROPAGATE;
 
 	switch (priv->middle_click_action) {
 	case GV_STATUS_ICON_MIDDLE_CLICK_TOGGLE:
@@ -261,7 +262,7 @@ on_button_release_event(GtkStatusIcon  *status_icon G_GNUC_UNUSED,
 		break;
 	}
 
-	return FALSE;
+	return GDK_EVENT_PROPAGATE;
 }
 
 static gboolean
@@ -302,7 +303,7 @@ on_scroll_event(GtkStatusIcon  *status_icon G_GNUC_UNUSED,
 		break;
 	}
 
-	return FALSE;
+	return GDK_EVENT_PROPAGATE;
 }
 
 static gboolean
@@ -507,11 +508,9 @@ gv_status_icon_setup_menu(GvStatusIcon *self)
 	GtkBuilder *builder;
 	GMenuModel *model;
 	GtkWidget *menu;
-	gchar *uifile;
 
 	/* Load the menu model */
-	gv_builder_load("status-icon-menu.glade", &builder, &uifile);
-	DEBUG("Popup menu built from ui file '%s'", uifile);
+	builder = gtk_builder_new_from_resource(UI_RESOURCE_PATH);
 
 	/* Build the menu */
 	model = G_MENU_MODEL(gtk_builder_get_object(builder, "status-icon-menu"));
@@ -524,7 +523,6 @@ gv_status_icon_setup_menu(GvStatusIcon *self)
 	priv->popup_menu = g_object_ref_sink(menu);
 
 	/* Cleanup */
-	g_free(uifile);
 	g_object_unref(builder);
 }
 
@@ -600,29 +598,29 @@ gv_status_icon_class_init(GvStatusIconClass *class)
 
 	properties[PROP_MIDDLE_CLICK_ACTION] =
 	        g_param_spec_enum("middle-click-action", "Middle click action", NULL,
-	                          GV_STATUS_ICON_MIDDLE_CLICK_ENUM_TYPE,
+	                          GV_TYPE_STATUS_ICON_MIDDLE_CLICK,
 	                          GV_STATUS_ICON_MIDDLE_CLICK_TOGGLE,
 	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
 
 	properties[PROP_SCROLL_ACTION] =
 	        g_param_spec_enum("scroll-action", "Scroll action", NULL,
-	                          GV_STATUS_ICON_SCROLL_ENUM_TYPE,
+	                          GV_TYPE_STATUS_ICON_SCROLL,
 	                          GV_STATUS_ICON_SCROLL_STATION,
 	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 
 	/* Register transform function */
-	g_value_register_transform_func(GV_STATUS_ICON_MIDDLE_CLICK_ENUM_TYPE,
+	g_value_register_transform_func(GV_TYPE_STATUS_ICON_MIDDLE_CLICK,
 	                                G_TYPE_STRING,
 	                                gv_value_transform_enum_string);
 	g_value_register_transform_func(G_TYPE_STRING,
-	                                GV_STATUS_ICON_MIDDLE_CLICK_ENUM_TYPE,
+	                                GV_TYPE_STATUS_ICON_MIDDLE_CLICK,
 	                                gv_value_transform_string_enum);
-	g_value_register_transform_func(GV_STATUS_ICON_SCROLL_ENUM_TYPE,
+	g_value_register_transform_func(GV_TYPE_STATUS_ICON_SCROLL,
 	                                G_TYPE_STRING,
 	                                gv_value_transform_enum_string);
 	g_value_register_transform_func(G_TYPE_STRING,
-	                                GV_STATUS_ICON_SCROLL_ENUM_TYPE,
+	                                GV_TYPE_STATUS_ICON_SCROLL,
 	                                gv_value_transform_string_enum);
 }
