@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2017 Arnaud Rebillout
+ * Copyright (C) 2015-2018 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -23,19 +23,8 @@
 #define __GOODVIBES_UI_GV_UI_HELPERS_H__
 
 #include <glib-object.h>
-#include <gtk/gtk.h>
-
-/*
- * GValue transform functions
- */
 
 void gv_value_transform_enum_string(const GValue *src_value, GValue *dest_value);
 void gv_value_transform_string_enum(const GValue *src_value, GValue *dest_value);
 
-/*
- * Gtk builder helpers
- */
-
-void gv_builder_load(const char *filename, GtkBuilder **builder, gchar **uifile);
-
 #endif /* __GOODVIBES_UI_GV_UI_HELPERS_H__ */
